@@ -5,7 +5,7 @@ DIE=0
 
 (autoconf --version) < /dev/null > /dev/null 2>&1 || {
 	echo
-	echo "You must have autoconf installed to compile GTK+."
+	echo "You must have autoconf installed to compile ThinIce."
 	echo "Download the appropriate package for your distribution,"
 	echo "or get the source tarball at ftp://ftp.gnu.org/pub/gnu/"
 	DIE=1
@@ -13,9 +13,8 @@ DIE=0
 
 (libtool --version) < /dev/null > /dev/null 2>&1 || {
 	echo
-	echo "You must have libtool installed to compile GTK+."
-	echo "Get ftp://alpha.gnu.org/gnu/libtool-1.2d.tar.gz"
-	echo "(or a newer version if it is available)"
+	echo "You must have libtool installed to compile ThinIce."
+	echo "Get it from ftp://ftp.gnu.org/pub/gnu/libtool/"
 	DIE=1
 }
 if test "$DIE" -eq 1; then
@@ -33,4 +32,4 @@ autoconf
 ./configure "$@"
 
 echo 
-echo "Now type 'make' to compile Thin Ice"
+echo "Now type 'make' to compile ThinIce"
